==> linuxconf_1.17r5.orig.tar.gz: linuxconf-1.17r5/fstab/fstab.pm <==
/* _dict.cc 14/08/1996 15.13.30 */
/* fixperm.cc 05/08/1998 21.25.42 */
PRIVATE void FIXPERM_SPEC::parsedev (SPEC_ONE&sp);
PUBLIC FIXPERM_SPEC::FIXPERM_SPEC (SPEC_ONE&sp);
PUBLIC int FIXPERM_SPEC::create (void);
PUBLIC int FIXPERM_SPEC::check (void);
PRIVATE void FIXPERM_SPECS::addline (const char *buf, SPEC_ONE&sp);
PUBLIC void FIXPERM_SPECS::addline (const char *buf);
PUBLIC int FIXPERM_SPECS::readspecf (const char *fname);
PUBLIC FIXPERM_SPECS::FIXPERM_SPECS (const char *fname);
PUBLIC FIXPERM_SPECS::FIXPERM_SPECS (void);
PUBLIC FIXPERM_SPEC *FIXPERM_SPECS::getitem (int no);
PUBLIC int FIXPERM_SPECS::check (bool boottime, bool silentflag);
PUBLIC int FIXPERM_SPECS::check (void);
PUBLIC FIXPERM_TASK::FIXPERM_TASK (void);
PUBLIC int FIXPERM_SPEC::edit (void);
/* fstab.cc 06/11/1999 23.15.12 */
/* fstab1.cc 07/12/1999 17.27.42 */
PUBLIC CONFIG_FILE_FSTAB::CONFIG_FILE_FSTAB (const char *_path,
	 bool _local,
	 const char *subsys);
PRIVATE void CONFIG_FILE_FSTAB::walk_do (FSTAB&fs,
	 bool del,
	 SSTREAM *ss)const;
PUBLIC int CONFIG_FILE_FSTAB::archive (SSTREAM&ss)const;
PUBLIC int CONFIG_FILE_FSTAB::extract (SSTREAM&ss);
PRIVATE void FSTAB_ENTRY::init (void);
PUBLIC FSTAB_ENTRY::FSTAB_ENTRY (void);
PUBLIC void FSTAB_ENTRY::parseopt (char *opts);
PUBLIC FSTAB_ENTRY::FSTAB_ENTRY (const char *line);
PUBLIC void FSTAB_ENTRY::format_opt (bool tosave, char *str)const;
PUBLIC void FSTAB_ENTRY::print (SSTREAM&ss)const;
PUBLIC int FSTAB_ENTRY::is_valid (void)const;
PUBLIC int FSTAB_ENTRY::is_auto (void);
PUBLIC int FSTAB_ENTRY::is_remote (void)const;
PUBLIC int FSTAB_ENTRY::is_swap (void)const;
PUBLIC bool FSTAB_ENTRY::has_quota_u (void)const;
PUBLIC bool FSTAB_ENTRY::has_quota_g (void)const;
PUBLIC FSTAB_ENTRY_TYPE FSTAB_ENTRY::gettype (void)const;
PUBLIC const char *FSTAB_ENTRY::getfs (void)const;
PUBLIC const char *FSTAB_ENTRY::getsource (void)const;
PUBLIC void FSTAB_ENTRY::setsource (const char *path);
PUBLIC const char *FSTAB_ENTRY::getmpoint (void)const;
PUBLIC const char *FSTAB_ENTRY::getcomment (void);
PUBLIC FSTAB::FSTAB (void);
PUBLIC FSTAB_ENTRY *FSTAB_GEN::getitem (int no);
PUBLIC int FSTAB::write (void);
/* fstab2.cc 03/12/1999 14.00.56 */
PUBLIC int FSTAB_ENTRY::umount_control (void);
PUBLIC int FSTAB_ENTRY::mount_control (void);
PUBLIC int FSTAB_ENTRY::edit (FSTAB_ENTRY_TYPE fstype);
PRIVATE int FSTAB::setmenu (DIALOG_LISTE&dia,
	 FSTAB_ENTRY_TYPE fstype,
	 FSTAB_ENTRY *tbsel[]);
PUBLIC void FSTAB::edit (FSTAB_ENTRY_TYPE fstype);
PUBLIC void FSTAB::control (FSTAB_ENTRY_TYPE fstype);
/* fstab3.cc 29/11/1997 20.53.36 */
PRIVATE void FSTAB::fixroot (FSTAB_ENTRY *root, char *status);
PUBLIC int FSTAB_ENTRY::check (void);
PUBLIC const char *FSTAB::getrootdev (void);
PUBLIC void FSTAB::check (void);
PUBLIC void FSTAB_ENTRY::quotacheck (void);
/* helpf.cc 14/08/1996 15.14.30 */
PUBLIC FSTAB_HELP_FILE::FSTAB_HELP_FILE (const char *fname);
/* mtab.cc 07/12/1999 17.28.10 */
PUBLIC MTAB::MTAB (void);
PUBLIC FSTAB_ENTRY *FSTAB_GEN::locate_mpoint (const char *str);
PUBLIC FSTAB_ENTRY *FSTAB_GEN::locate_source (const char *str);
PUBLIC int FSTAB_ENTRY::domount (void);
PUBLIC int FSTAB_ENTRY::doumount (void);
PUBLIC bool FSTAB_ENTRY::is_mounted (void);
/* nfs.cc 26/05/1995 12.41.58 */
/* partition.cc 19/11/1999 11.34.28 */
PUBLIC PARTITION::PARTITION (const char *_dev,
	 int _id,
	 long _size,
	 const char *_mpoint);
PUBLIC PARTITION::~PARTITION (void);
PUBLIC void PARTITION::setdosdrive (char letter);
PUBLIC char PARTITION::getdosdrive (void);
PUBLIC int PARTITION::isdos (void);
PUBLIC int PARTITION::isos2 (void);
PUBLIC int PARTITION::isswap (void);
PUBLIC int PARTITION::islinux (void);
PUBLIC const char *PARTITION::getdevice (void);
PUBLIC long PARTITION::getsize (void);
PUBLIC int PARTITION::getid (void);
PUBLIC void PARTITION::formatinfo (char *buf, bool show_mount);
PUBLIC const char *PARTITION::getos (void);
PUBLIC int PARTITIONS::load (void);
PUBLIC PARTITION *PARTITIONS::getitem (int no)const;
PUBLIC PARTITION *PARTITIONS::getitem (const char *device)const;
PROTECTED void PARTITIONS::setdosdrive (void);
PUBLIC PARTITIONS::PARTITIONS (void);
/* quota.cc 29/08/1999 18.14.26 */
PRIVATE void QUOTA_SPEC::init (void);
PUBLIC void QUOTA_SPEC::reset (void);
PUBLIC bool QUOTA_SPEC::isdiff (const QUOTA_SPEC&s)const;
PUBLIC QUOTA_SPEC::QUOTA_SPEC (void);
PUBLIC QUOTA_SPEC::QUOTA_SPEC (const char *val);
PUBLIC QUOTA_SPEC::QUOTA_SPEC (const QUOTA_SPEC *s);
PUBLIC void QUOTA_SPEC::setfrom (const QUOTA_SPEC *s);
PUBLIC void QUOTA_SPEC::setfrom (const char *val);
PUBLIC void QUOTA_SPEC::write (CONFDB&conf,
	 const char *key,
	 const char *device);
PUBLIC QUOTA_SPECS::QUOTA_SPECS (CONFDB&conf,
	 const char *key,
	 const char *device);
PUBLIC QUOTA_SPECS::QUOTA_SPECS (void);
PUBLIC void QUOTA_SPECS::write (CONFDB&conf,
	 const char *key,
	 const char *device);
PUBLIC QUOTA_SPEC *QUOTA_SPECS::getitem (int no)const;
PUBLIC QUOTA_SPEC *QUOTA_SPECS::getitem (const char *name)const;
PUBLIC QUOTA_DEV::QUOTA_DEV (CONFDB&conf, const char *device);
PUBLIC void QUOTA_DEV::write (CONFDB&conf);
PUBLIC void QUOTA_DEV::geteffuserspec (const char *name,
	 const char *group,
	 QUOTA_SPEC&eff);
PUBLIC void QUOTA_DEV::geteffgroupspec (const char *group,
	 QUOTA_SPEC&eff);
PUBLIC QUOTA_SPEC *QUOTA_DEV::getuserspec (const char *name);
PUBLIC QUOTA_SPEC *QUOTA_DEV::getgroupspec (const char *name);
PUBLIC QUOTA_SPEC *QUOTA_DEV::getuserdef_gspec (const char *name);
PUBLIC void QUOTA_DEV::deluserspec (const char *name);
PUBLIC void QUOTA_DEV::delgroupspec (const char *name);
PUBLIC void QUOTA_DEV::deluserdef_gspec (const char *name);
PUBLIC void QUOTA_DEV::applyone (struct passwd *p);
PUBLIC void QUOTA_DEV::applyall (void);
PUBLIC QUOTA_DEV *QUOTA_DEVS::getitem (int no)const;
PUBLIC QUOTACTL::QUOTACTL (void);
PUBLIC QUOTACTL::~QUOTACTL (void);
PUBLIC int QUOTACTL::write (PRIVILEGE *priv);
PUBLIC void QUOTA_SPEC::setupdia (DIALOG&dia);
PUBLIC void QUOTACTL::editdef (void);
PUBLIC void QUOTACTL::applyall (void);
PUBLIC void QUOTACTL::applyall (const char *dev);
PUBLIC int QUOTACTL::applyone (const char *user);
PRIVATE QUOTA_SPEC *QUOTA_EDIT::getspec (QUOTA_DEV *d);
PUBLIC int QUOTA_EDIT::deluser (PRIVILEGE *priv);
PRIVATE void QUOTA_EDIT::geteffspec (QUOTA_DEV *d, QUOTA_SPEC&eff);
PUBLIC QUOTA_EDIT::QUOTA_EDIT (const char *_name, QUOTA_TYPE type);
PUBLIC void QUOTA_EDIT::setname (const char *_name);
PUBLIC void QUOTA_EDIT::setgroup (const char *grp);
PUBLIC QUOTA_EDIT::~QUOTA_EDIT (void);
PUBLIC int QUOTA_EDIT::save (PRIVILEGE *priv);
PUBLIC void QUOTA_EDIT::setupdia (DIALOG&dia, const char *maintitle);

==> linuxconf_1.26r4.orig.tar.gz: linuxconf-1.26r4/fstab/fstab.pm <==
/* _dict.cc 14/08/1996 15.13.30 */
/* fixperm.cc 21/01/2001 22.58.22 */
PRIVATE void FIXPERM_SPEC::parsedev (SPEC_ONE&sp);
PUBLIC FIXPERM_SPEC::FIXPERM_SPEC (SPEC_ONE&sp);
PUBLIC int FIXPERM_SPEC::create (PERMINFO&p);
PUBLIC int FIXPERM_SPEC::check (void);
PRIVATE void FIXPERM_SPECS::addline (const char *buf, SPEC_ONE&sp);
PUBLIC void FIXPERM_SPECS::addline (const char *buf);
PUBLIC int FIXPERM_SPECS::readspecf (const char *fname);
PUBLIC FIXPERM_SPECS::FIXPERM_SPECS (const char *fname);
PUBLIC FIXPERM_SPECS::FIXPERM_SPECS (void);
PUBLIC FIXPERM_SPEC *FIXPERM_SPECS::getitem (int no);
PUBLIC int FIXPERM_SPECS::check (bool boottime, bool silentflag);
PUBLIC int FIXPERM_SPECS::check (void);
PUBLIC FIXPERM_TASK::FIXPERM_TASK (void);
PUBLIC int FIXPERM_SPEC::edit (void);
/* fstab1.cc 25/11/2000 14.30.54 */
PUBLIC CONFIG_FILE_FSTAB::CONFIG_FILE_FSTAB (const char *_path,
	 bool _local,
	 const char *subsys);
PRIVATE void CONFIG_FILE_FSTAB::walk_do (FSTAB&fs,
	 bool del,
	 SSTREAM *ss)const;
PUBLIC int CONFIG_FILE_FSTAB::archive (SSTREAM&ss)const;
PUBLIC int CONFIG_FILE_FSTAB::extract (SSTREAM&ss);
PRIVATE void FSTAB_ENTRY::init (void);
PUBLIC FSTAB_ENTRY::FSTAB_ENTRY (void);
PUBLIC void FSTAB_ENTRY::parseopt (char *opts);
PUBLIC FSTAB_ENTRY::FSTAB_ENTRY (const char *line);
PUBLIC void FSTAB_ENTRY::format_opt (bool tosave, char *str)const;
PUBLIC void FSTAB_ENTRY::print (SSTREAM&ss)const;
PUBLIC int FSTAB_ENTRY::is_valid (void)const;
PUBLIC int FSTAB_ENTRY::is_auto (void);
PUBLIC int FSTAB_ENTRY::is_remote (void)const;
PUBLIC int FSTAB_ENTRY::is_swap (void)const;
PUBLIC bool FSTAB_ENTRY::has_quota_u (void)const;
PUBLIC bool FSTAB_ENTRY::has_quota_g (void)const;
PUBLIC FSTAB_ENTRY_TYPE FSTAB_ENTRY::gettype (void)const;
PUBLIC const char *FSTAB_ENTRY::getfs (void)const;
PUBLIC const char *FSTAB_ENTRY::getsource (void)const;
PUBLIC void FSTAB_ENTRY::setsource (const char *path);
PUBLIC const char *FSTAB_ENTRY::getmpoint (void)const;
PUBLIC const char *FSTAB_ENTRY::getcomment (void);
PUBLIC FSTAB::FSTAB (void);
PUBLIC FSTAB_ENTRY *FSTAB_GEN::getitem (int no);
PUBLIC int FSTAB::write (void);
/* fstab2.cc 19/01/2001 00.55.44 */
PUBLIC int FSTAB_ENTRY::umount_control (void);
PUBLIC int FSTAB_ENTRY::mount_control (void);
PUBLIC int FSTAB_ENTRY::edit (FSTAB_ENTRY_TYPE fstype);
PRIVATE int FSTAB::setmenu (DIALOG_LISTE&dia,
	 FSTAB_ENTRY_TYPE fstype,
	 FSTAB_ENTRY *tbsel[]);
PUBLIC void FSTAB::edit (FSTAB_ENTRY_TYPE fstype);
PUBLIC void FSTAB::control (FSTAB_ENTRY_TYPE fstype);
/* fstab3.cc 19/02/2001 15.37.16 */
PRIVATE void FSTAB::fixroot (FSTAB_ENTRY *root, char *status);
PUBLIC int FSTAB_ENTRY::check (void);
PUBLIC const char *FSTAB::getrootdev (void);
PUBLIC void FSTAB::check (void);
PUBLIC void FSTAB_ENTRY::quotacheck (void);
/* fstab.cc 17/04/2001 01.44.08 */
/* helpf.cc 14/08/1996 15.14.30 */
PUBLIC FSTAB_HELP_FILE::FSTAB_HELP_FILE (const char *fname);
/* mtab.cc 22/08/2000 10.49.06 */
PUBLIC MTAB::MTAB (void);
PUBLIC FSTAB_ENTRY *FSTAB_GEN::locate_mpoint (const char *str);
PUBLIC FSTAB_ENTRY *FSTAB_GEN::locate_source (const char *str);
PUBLIC int FSTAB_ENTRY::domount (void);
PUBLIC int FSTAB_ENTRY::doumount (void);
PUBLIC bool FSTAB_ENTRY::is_mounted (void);
/* nfs.cc 26/05/1995 12.41.58 */
/* partition.cc 02/11/2000 10.03.18 */
PUBLIC PARTITION::PARTITION (const char *_dev,
	 int _id,
	 long _size,
	 const char *_mpoint);
PUBLIC PARTITION::~PARTITION (void);
PUBLIC void PARTITION::setdosdrive (char letter);
PUBLIC char PARTITION::getdosdrive (void);
PUBLIC int PARTITION::isdos (void);
PUBLIC int PARTITION::isos2 (void);
PUBLIC int PARTITION::isswap (void);
PUBLIC int PARTITION::islinux (void);
PUBLIC const char *PARTITION::getdevice (void);
PUBLIC long PARTITION::getsize (void);
PUBLIC int PARTITION::getid (void);
PUBLIC void PARTITION::formatinfo (char *buf, bool show_mount);
PUBLIC const char *PARTITION::getos (void);
PUBLIC int PARTITION::readlabel (SSTRING&s);
PUBLIC int PARTITIONS::load (void);
PUBLIC PARTITION *PARTITIONS::getitem (int no)const;
PUBLIC PARTITION *PARTITIONS::getitem (const char *device)const;
PROTECTED void PARTITIONS::setdosdrive (void);
PUBLIC PARTITIONS::PARTITIONS (void);
/* quota.cc 17/04/2001 01.39.28 */
PRIVATE void QUOTA_SPEC::init (void);
PUBLIC void QUOTA_SPEC::reset (void);
PUBLIC bool QUOTA_SPEC::isdiff (const QUOTA_SPEC&s)const;
PUBLIC QUOTA_SPEC::QUOTA_SPEC (void);
PUBLIC QUOTA_SPEC::QUOTA_SPEC (const char *val);
PUBLIC QUOTA_SPEC::QUOTA_SPEC (const QUOTA_SPEC *s);
PUBLIC void QUOTA_SPEC::setfrom (const QUOTA_SPEC *s);
PUBLIC void QUOTA_SPEC::setfrom (const char *val);
PUBLIC void QUOTA_SPEC::write (CONFDB&conf,
	 const char *key,
	 const char *device);
PUBLIC QUOTA_SPECS::QUOTA_SPECS (CONFDB&conf,
	 const char *key,
	 const char *device);
PUBLIC QUOTA_SPECS::QUOTA_SPECS (void);
PUBLIC void QUOTA_SPECS::write (CONFDB&conf,
	 const char *key,
	 const char *device);
PUBLIC QUOTA_SPEC *QUOTA_SPECS::getitem (int no)const;
PUBLIC QUOTA_SPEC *QUOTA_SPECS::getitem (const char *name)const;
PUBLIC QUOTA_DEV::QUOTA_DEV (CONFDB&conf, const char *device);
PUBLIC void QUOTA_DEV::write (CONFDB&conf);
PUBLIC void QUOTA_DEV::geteffuserspec (const char *name,
	 const char *group,
	 QUOTA_SPEC&eff);
PUBLIC void QUOTA_DEV::geteffgroupspec (const char *group,
	 QUOTA_SPEC&eff);
PUBLIC QUOTA_SPEC *QUOTA_DEV::getuserspec (const char *name);
PUBLIC QUOTA_SPEC *QUOTA_DEV::getgroupspec (const char *name);
PUBLIC QUOTA_SPEC *QUOTA_DEV::getuserdef_gspec (const char *name);
PUBLIC void QUOTA_DEV::deluserspec (const char *name);
PUBLIC void QUOTA_DEV::delgroupspec (const char *name);
PUBLIC void QUOTA_DEV::deluserdef_gspec (const char *name);
PUBLIC void QUOTA_DEV::applyone (struct passwd *p);
PUBLIC int QUOTA_DEV::setrealdevice (void);
PUBLIC void QUOTA_DEV::applyall (void);
PUBLIC QUOTA_DEV *QUOTA_DEVS::getitem (int no)const;
PUBLIC QUOTACTL::QUOTACTL (void);
PUBLIC QUOTACTL::~QUOTACTL (void);
PUBLIC int QUOTACTL::write (PRIVILEGE *priv);
PUBLIC void QUOTA_SPEC::setupdia (DIALOG&dia);
PUBLIC void QUOTACTL::editdef (void);
PUBLIC void QUOTACTL::applyall (void);
PUBLIC void QUOTACTL::applyall (const char *dev);
PUBLIC int QUOTACTL::applyone (const char *user);
PRIVATE QUOTA_SPEC *QUOTA_EDIT::getspec (QUOTA_DEV *d);
PUBLIC int QUOTA_EDIT::deluser (PRIVILEGE *priv);
PRIVATE void QUOTA_EDIT::geteffspec (QUOTA_DEV *d, QUOTA_SPEC&eff);
PUBLIC QUOTA_EDIT::QUOTA_EDIT (const char *_name, QUOTA_TYPE type);
PUBLIC void QUOTA_EDIT::setname (const char *_name);
PUBLIC void QUOTA_EDIT::setgroup (const char *grp);
PUBLIC QUOTA_EDIT::~QUOTA_EDIT (void);
PUBLIC int QUOTA_EDIT::save (PRIVILEGE *priv);
PUBLIC void QUOTA_EDIT::setupdia (DIALOG&dia, const char *maintitle);
PUBLIC QUOTA_DEV *QUOTACTL::getdev (const char *device);
